@@ -3,20 +3,20 @@ package Test2::Event::Warning;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use parent 'Test2::Event';
 
-use Test2::Util::HashBase qw( warning );
+use Test2::Util::HashBase qw( causes_fail warning );
 
 sub init {
-    $_[0]->{ +WARNING } = 'undef' unless defined $_[0]->{ +WARNING };
+    $_[0]->{ +CAUSES_FAIL } = 1       unless exists $_[0]->{ +CAUSES_FAIL };
+    $_[0]->{ +WARNING }     = 'undef' unless defined $_[0]->{ +WARNING };
 }
 
-sub summary { 'Unexpected warning: ' . $_[0]->{ +WARNING } }
+sub summary { $_[0]->{ +WARNING } }
 
-sub causes_fail      {1}
-sub increments_count {1}
+sub increments_count {0}
 sub diagnostics      {1}
 
 1;
@@ -35,7 +35,7 @@ Test2::Event::Warning - A Test2 event for warnings
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 DESCRIPTION
 
